@@ -1,7 +1,7 @@
 """
 Type annotations for route53-recovery-cluster service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/type_defs.html)
 
 Usage::
 
